Imagefindpars: Source finding parameters — drizzlepac 1.0.6 (14-Aug-2012) documentation

### Navigation

- index
- modules |
- drizzlepac 1.0.6 (14-Aug-2012) documentation »

# Imagefindpars: Source finding parameters

This interface provides a mechanism for setting the parameters used by the built-in source finding algorithm based on the published algorithms used by DAOFIND.

imagefindpars Version 1.0.2 updated on 11-Apr-2012

These parameters control the operation of the algorithm that extracts sources from the image as called by TWEAKREG: Alignment of Images. The algorithm implemented follows the concepts defined by DAOFIND (without actually using any DAOFIND code).

Input:
| The algorithm simply requires the image to be read in as a numpy array, along with the user specified parameters given here.
Output:
| The primary output, as used by TWEAKREG: Alignment of Images, is a list of numpy arrays representing the X and Y positions of detected sources along with flux for each source.

## Parameters

computesig : bool

  This parameter controls whether or not to automatically compute a sigma value to be used for object identification. If set to True, then the value computed will override any user input for the parameter ‘skysigma’. The automatic sigma value gets computed from each input exposure as:

      1.5 * imstatistics(image,nclip=3,fields='stddev')

This single value will then be used for object identification for all input exposures. [Default: Yes]

skysigma : float
  The standard deviation of the sky pixels. This value will only be used if computesig is False. [Default: 0.0]
conv_width : float
  The convolution kernel width in pixels. Recommended values (~2x the PSF FWHM): ACS/WFC & WFC3/UVIS ~3.5 pix and WFC3/IR ~2.5 pix. [Default: 3.5]
peakmin : float
  This parameter allows the user to select only those sources whose peak value (in the units of the input image) is greater than this value. [Default: None]
peakmax : float
  This parameter allows the user to select only those sources whose peak value (in the units of the input image) is less than this value. [Default: None]
threshold : float
  The object detection threshold above the local background in units of sigma. [Default: 4.0]
nsigma : float
  The semi-major axis of the Gaussian convolution kernel used to compute the density enhancement and mean density images in Gaussian sigma. [Default: 1.5]
fluxmin : float
  This parameter allows the user to select only those sources whose total flux (in the units of the input image) is greater than this value. [Default: None]
fluxmax : float
  This parameter allows the user to select only those sources whose total flux (in the units of the input image) is less than this value. [Default: None]

`drizzlepac.imagefindpars.` `getHelpAsString`(docstring=False)

  Teal help function to describe the parameters being set Descriptions of parameters come from .help file

`drizzlepac.imagefindpars.` `help`()

### Navigation

- index
- modules |
- drizzlepac 1.0.6 (14-Aug-2012) documentation »